betty.cli.commands.clear_caches module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.cli.commands.clear_caches module

final class betty.cli.commands.clear_caches.ClearCaches

  Bases: `ShorthandPluginBase`, `AppDependentFactory`, `Command`

  A command to clear all Betty caches.

  __init__(app: App)
  async click_command() → click.Command

    Get the plugin’s Click command.

  async classmethod new_for_app(app: App) → Self

    Create a new instance using the given app.